/// <reference types="react" />
import { Animated, LayoutChangeEvent, TextStyle, ViewStyle } from 'react-native';
import { BaseModal } from './ModalCenter';
import { OptionItemProps } from './OptionItem';
import BaseComponent from '../BaseComponent';
import { ThemeVars } from '../../modules/theme/ThemeBuilder';
import EndCallback = Animated.EndCallback;
export interface ActionModal extends BaseModal {
    title?: string | JSX.Element;
    containerStyle?: ViewStyle;
    body?: string | JSX.Element;
    actions?: ModalActionAction[];
    actionReturn?: string;
    maxWidth?: number;
    onReturn: () => void;
}
export interface ModalActionAction extends OptionItemProps {
    title: string;
    onPress: () => void;
}
export declare type ModalActionItemProps = {
    item: ActionModal;
    onHide: () => void;
};
export declare type State = {
    fade: Animated.Value;
    bottom: Animated.Value;
    width: number;
    height: number;
    isVisible: boolean;
};
export default class ModalActionItem extends BaseComponent<ModalActionItemProps, State> {
    state: {
        fade: Animated.Value;
        bottom: Animated.Value;
        width: number;
        height: number;
        isVisible: boolean;
    };
    private onDimensionsChangeListener;
    private animation;
    componentDidMount(): Promise<void>;
    onLayout(event: LayoutChangeEvent): void;
    show(): void;
    componentWillUnmount(): void;
    hide(cb: EndCallback): void;
    onReturn(): void;
    render(): JSX.Element;
    loadStyles(theme: ThemeVars): {
        returnButton: {
            flex: number;
        };
        actionsContainer: {
            marginBottom: number;
        };
        container: ViewStyle;
        backdrop: ViewStyle;
        footer: ViewStyle;
        title: TextStyle;
        header: ViewStyle;
        body: ViewStyle;
        bodyText: TextStyle;
        content: ViewStyle;
    };
}
